==> 0.0.2.tar.gz: android/src/main/java/com/yifan/yf_ads/views/draw/DrawFeedVideoView.java <==
package com.yifan.yf_ads.views.draw;


import android.app.Activity;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.yifan.yf_ads.R;
import com.yifan.yf_ads.admanager.CommonAdManager;
import com.yifan.yf_ads.admanager.DrawFeedVideoAdManager;
import com.yifan.yf_ads.bean.DrawFeedVideoBean;
import com.yifan.yf_ads.utils.Constants;
import com.yifan.yf_ads.utils.FLog;

import io.flutter.plugin.common.EventChannel;
import io.flutter.plugin.platform.PlatformView;

/**
 * 一句话描述该类功能.
 *
 * @author JamesQian
 * @version 1.0
 * @copyright 亿帆
 * @date 2024/1/26 13:49
 **/
public class DrawFeedVideoView implements PlatformView {

    private final String TAG = "NativeDrawFeedVideoView";

    private DrawFeedVideoAdManager nativeDrawFeedVideoAdManager;

    @NonNull
    private ViewGroup containerView;

    DrawFeedVideoView(@NonNull final Activity activity, final int id, @Nullable final DrawFeedVideoBean creationParams, final EventChannel.EventSink eventSink) {
        FLog.i(TAG, "DrawNativeExpressVideoView id = " + id);
        if (creationParams == null) {
            return;
        }
        int resourceId = creationParams.getDrawFeedPageLayoutId();
        int curResourceLayoutId = resourceId <= 0 ? R.layout.yf_flutter_draw_page_view : resourceId;
        containerView = (ViewGroup) LayoutInflater.from(activity.getApplicationContext()).inflate(curResourceLayoutId, null);
        if (nativeDrawFeedVideoAdManager == null) {
            nativeDrawFeedVideoAdManager = new DrawFeedVideoAdManager(activity, Constants.AD_TYPE_NATIVE_DRAW_FEED_VIDEO);
        }
        nativeDrawFeedVideoAdManager.setAdListener(new CommonAdManager.AdListener() {
            @Override
            public void onAdClose() {

            }

            @Override
            public void onAdLoadSuccess() {
                nativeDrawFeedVideoAdManager.showAds(activity, containerView);
            }

            @Override
            public void onAdLoadFail(String errorMessage) {

            }
        });
        nativeDrawFeedVideoAdManager.requestNativeDrawFeedVideoAD(id, creationParams, eventSink);
    }

    @Override
    public View getView() {
        return containerView;
    }

    @Override
    public void dispose() {
        FLog.i(TAG, "dispose");
        releaseAd();
    }

    public void releaseAd() {
        if (nativeDrawFeedVideoAdManager != null) {
            nativeDrawFeedVideoAdManager.destroy();
        }
    }
}

==> 0.0.9.tar.gz: android/src/main/java/com/yifan/yf_ads/views/draw/DrawFeedVideoView.java <==
package com.yifan.yf_ads.views.draw;


import android.app.Activity;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;

import androidx.annotation.NonNull;
import androidx.annotation.Nullable;

import com.yifan.yf_ads.R;
import com.yifan.yf_ads.admanager.CommonAdManager;
import com.yifan.yf_ads.admanager.DrawFeedVideoAdManager;
import com.yifan.yf_ads.bean.DrawFeedVideoBean;
import com.yifan.yf_ads.utils.Constants;
import com.yifan.yf_ads.utils.FLog;

import io.flutter.plugin.common.EventChannel;
import io.flutter.plugin.platform.PlatformView;

/**
 * 一句话描述该类功能.
 *
 * @author JamesQian
 * @version 1.0
 * @copyright 亿帆
 * @date 2024/1/26 13:49
 **/
public class DrawFeedVideoView implements PlatformView {

    private final String TAG = "NativeDrawFeedVideoView";

    private DrawFeedVideoAdManager nativeDrawFeedVideoAdManager;

    @NonNull
    private ViewGroup containerView;

    DrawFeedVideoView(@NonNull final Activity activity, final String id, @Nullable final DrawFeedVideoBean creationParams, final EventChannel.EventSink eventSink) {
        FLog.i(TAG, "DrawNativeExpressVideoView id = " + id);
        if (creationParams == null) {
            return;
        }
        int resourceId = creationParams.getDrawFeedPageLayoutId();
        int curResourceLayoutId = resourceId <= 0 ? R.layout.yf_flutter_draw_page_view : resourceId;
        containerView = (ViewGroup) LayoutInflater.from(activity.getApplicationContext()).inflate(curResourceLayoutId, null);
        if (nativeDrawFeedVideoAdManager == null) {
            nativeDrawFeedVideoAdManager = new DrawFeedVideoAdManager(activity, Constants.AD_TYPE_NATIVE_DRAW_FEED_VIDEO);
        }
        nativeDrawFeedVideoAdManager.setAdListener(new CommonAdManager.AdListener() {
            @Override
            public void onAdClose() {

            }

            @Override
            public void onAdLoadSuccess() {
                nativeDrawFeedVideoAdManager.showAds(activity, containerView);
            }

            @Override
            public void onAdLoadFail(String errorMessage) {

            }
        });
        nativeDrawFeedVideoAdManager.requestNativeDrawFeedVideoAD(id, creationParams, eventSink);
    }

    @Override
    public View getView() {
        return containerView;
    }

    @Override
    public void dispose() {
        FLog.i(TAG, "dispose");
        releaseAd();
    }

    public void releaseAd() {
        if (nativeDrawFeedVideoAdManager != null) {
            nativeDrawFeedVideoAdManager.destroy();
        }
    }
}
